@@ -225,12 +225,12 @@ int main(int argc, char *argv[])
 
 	progname = argv[0];
 
-	if (argc >= 2) {
+	if (argc > 2) {
 		fprintf(stderr, "Usage: %s [file]\n", progname);
 		return 1;
 	}
 
-	if (argc >= 1 && strcmp(argv[1], "-")) {
+	if (argc > 1 && strcmp(argv[1], "-")) {
 		fd = open(argv[1], O_RDONLY);
 		if ( fd < 0 ) {
 			perror(argv[1]);
